============
rebotics_sdk
============

Rebotics SDK for communicating with Rebotic Services, API CLI client.



Features
--------

* Communication between Rebotics Services through provider client classes
* Two django applications for external communications through web-hooks
* CLI clients for Rebotics Services

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
